@@ -1,6 +1,6 @@
-from external.a79.src.a79.client import A79Client
-from external.a79.src.models.tools import DEFAULT
-from external.a79.src.models.tools.call_task_generator_models import (
+from ..client import A79Client
+from ..models.tools import DEFAULT
+from ..models.tools.call_task_generator_models import (
     CallTaskDefinition,
     CallTaskGeneratorInput,
     CallTaskGeneratorOutput,
