@@ -3,19 +3,33 @@ from typing import Any
 from ..client import A79Client
 from ..models.tools import DEFAULT
 from ..models.tools.nl_to_sql_models import (
+    DatabaseCredentials,
+    DatabaseHierarchy,
+    DatabaseSelection,
+    Enum,
     NLToSQLInput,
     NLToSQLOutput,
+    SchemaSelection,
     SourceSelectionInput,
     SourceSelectionOutput,
     SQADatabaseConfig,
+    SqlDialect,
+    SqlType,
 )
 
 __all__ = [
+    "DatabaseCredentials",
+    "DatabaseHierarchy",
+    "DatabaseSelection",
+    "Enum",
     "NLToSQLInput",
     "NLToSQLOutput",
     "SQADatabaseConfig",
+    "SchemaSelection",
     "SourceSelectionInput",
     "SourceSelectionOutput",
+    "SqlDialect",
+    "SqlType",
     "generate_sql",
 ]
 
