@@ -1,9 +1,6 @@
-from external.a79.src.a79.client import A79Client
-from external.a79.src.models.tools import DEFAULT
-from external.a79.src.models.tools.react_agent_models import (
-    ReactAgentInput,
-    ReactAgentOutput,
-)
+from ..client import A79Client
+from ..models.tools import DEFAULT
+from ..models.tools.react_agent_models import ReactAgentInput, ReactAgentOutput
 
 __all__ = ["ReactAgentInput", "ReactAgentOutput", "react_agent"]
 
